# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class GetSecGroupResult(object):
    """
    A collection of values returned by getSecGroup.
    """
    def __init__(__self__, region=None, tenant_id=None):
        if region and not isinstance(region, basestring):
            raise TypeError('Expected argument region to be a basestring')
        __self__.region = region
        """
        See Argument Reference above.
        """
        if tenant_id and not isinstance(tenant_id, basestring):
            raise TypeError('Expected argument tenant_id to be a basestring')
        __self__.tenant_id = tenant_id

def get_sec_group(name=None, region=None, secgroup_id=None, tenant_id=None):
    """
    Use this data source to get the ID of an available OpenStack security group.
    """
    __args__ = dict()

    __args__['name'] = name
    __args__['region'] = region
    __args__['secgroupId'] = secgroup_id
    __args__['tenantId'] = tenant_id
    __ret__ = pulumi.runtime.invoke('openstack:networking/getSecGroup:getSecGroup', __args__)

    return GetSecGroupResult(
        region=__ret__.get('region'),
        tenant_id=__ret__.get('tenantId'))
