# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

__config__ = pulumi.Config('openstack')

auth_url = __config__.get('authUrl')
"""
The Identity authentication URL.
"""

cacert_file = __config__.get('cacertFile')
"""
A Custom CA certificate.
"""

cert = __config__.get('cert')
"""
A client certificate to authenticate with.
"""

cloud = __config__.get('cloud')
"""
An entry in a `clouds.yaml` file to use.
"""

domain_id = __config__.get('domainId')
"""
The ID of the Domain to scope to (Identity v3).
"""

domain_name = __config__.get('domainName')
"""
The name of the Domain to scope to (Identity v3).
"""

endpoint_type = __config__.get('endpointType')

insecure = __config__.get('insecure')
"""
Trust self-signed certificates.
"""

key = __config__.get('key')
"""
A client private key to authenticate with.
"""

password = __config__.get('password')
"""
Password to login with.
"""

project_domain_id = __config__.get('projectDomainId')
"""
The ID of the domain where the proejct resides (Identity v3).
"""

project_domain_name = __config__.get('projectDomainName')
"""
The name of the domain where the project resides (Identity v3).
"""

region = __config__.get('region')
"""
The OpenStack region to connect to.
"""

swauth = __config__.get('swauth')
"""
Use Swift's authentication system instead of Keystone. Only used for interaction with Swift.
"""

tenant_id = __config__.get('tenantId')
"""
The ID of the Tenant (Identity v2) or Project (Identity v3) to login with.
"""

tenant_name = __config__.get('tenantName')
"""
The name of the Tenant (Identity v2) or Project (Identity v3) to login with.
"""

token = __config__.get('token')
"""
Authentication token to use as an alternative to username/password.
"""

use_octavia = __config__.get('useOctavia')
"""
If set to `true`, API requests will go the Load Balancer service (Octavia) instead of the Networking service (Neutron).
"""

user_domain_id = __config__.get('userDomainId')
"""
The ID of the domain where the user resides (Identity v3).
"""

user_domain_name = __config__.get('userDomainName')
"""
The name of the domain where the user resides (Identity v3).
"""

user_id = __config__.get('userId')
"""
Username to login with.
"""

user_name = __config__.get('userName')
"""
Username to login with.
"""

